==> coregtk-3.10.0.zip: coregtk-3.10.0/docs/html/interface_c_g_t_k_text_view.js <==
var interface_c_g_t_k_text_view =
[
    [ "addChildAtAnchorWithChild:andAnchor:", "interface_c_g_t_k_text_view.html#a785055611ec95ba45b3500b28c510f8e", null ],
    [ "addChildInWindowWithChild:andWhichWindow:andXpos:andYpos:", "interface_c_g_t_k_text_view.html#a53988e3b584cfda099218bf0b817fa3b", null ],
    [ "backwardDisplayLine:", "interface_c_g_t_k_text_view.html#a3aafd7992d437ebaaffc7c7343e6b93f", null ],
    [ "backwardDisplayLineStart:", "interface_c_g_t_k_text_view.html#a4e597cc1e3729a9ff67114e3c730d8ec", null ],
    [ "bufferToWindowCoordsWithWin:andBufferX:andBufferY:andWindowX:andWindowY:", "interface_c_g_t_k_text_view.html#a1b696a6ce9a3e8fe3cff0ba1b5f43a18", null ],
    [ "forwardDisplayLine:", "interface_c_g_t_k_text_view.html#a3a52fbcb4d12672f4f1103243407185b", null ],
    [ "forwardDisplayLineEnd:", "interface_c_g_t_k_text_view.html#afadc02a0e13b75cbb9034bd1be1fed68", null ],
    [ "getAcceptsTab", "interface_c_g_t_k_text_view.html#a09ee78b7970cacbfc8ca03f296d376f7", null ],
    [ "getBorderWindowSize:", "interface_c_g_t_k_text_view.html#a26d99de7816944dd7fa173cbed033dc4", null ],
    [ "getBuffer", "interface_c_g_t_k_text_view.html#abcaf6b1ec97e5dfc0bc140d37b0fba80", null ],
    [ "getCursorLocationsWithIter:andStrong:andWeak:", "interface_c_g_t_k_text_view.html#aa15c56fd47bc31c9b13825ab06d37c90", null ],
    [ "getCursorVisible", "interface_c_g_t_k_text_view.html#a1d53af03ae4df2ecb50c87eaf6fa5a01", null ],
    [ "getDefaultAttributes", "interface_c_g_t_k_text_view.html#a013ec9642813657b97b74e3880172774", null ],
    [ "getEditable", "interface_c_g_t_k_text_view.html#ac32345742c15e5800eb83ae80a4bd85c", null ],
    [ "getHadjustment", "interface_c_g_t_k_text_view.html#a10830068739dd1367a229146d7726ec8", null ],
    [ "getIndent", "interface_c_g_t_k_text_view.html#a0ee52b65855a553b85a9755c6c26beea", null ],
    [ "getInputHints", "interface_c_g_t_k_text_view.html#af1dbccba4d882f55748bf6ab48b55ca2", null ],
    [ "getInputPurpose", "interface_c_g_t_k_text_view.html#aa7eccee2c32eb8a4b4499462731cc5a5", null ],
    [ "getIterAtLocationWithIter:andX:andY:", "interface_c_g_t_k_text_view.html#aaa6bb40a1d1ac27c130e6595c35ad93a", null ],
    [ "getIterAtPositionWithIter:andTrailing:andX:andY:", "interface_c_g_t_k_text_view.html#a9054c2de391f7f08928c2348a1e651d6", null ],
    [ "getIterLocationWithIter:andLocation:", "interface_c_g_t_k_text_view.html#a3c63cd5e67feb2ac8c2100058e47bf6f", null ],
    [ "getJustification", "interface_c_g_t_k_text_view.html#a62c998ca5364e66b4ace5b7d0c73761e", null ],
    [ "getLeftMargin", "interface_c_g_t_k_text_view.html#a66db5566c75685c873f5f71f43413a63", null ],
    [ "getLineAtYWithTargetIter:andY:andLineTop:", "interface_c_g_t_k_text_view.html#aa8919f0d82d91aa9e4c8a09c0cc50d8d", null ],
    [ "getLineYrangeWithIter:andY:andHeight:", "interface_c_g_t_k_text_view.html#af6f6f423ef35b97047c14785de2acf61", null ],
    [ "getOverwrite", "interface_c_g_t_k_text_view.html#ab6cbc76a44bc1e921ebdd647162b0fa1", null ],
    [ "getPixelsAboveLines", "interface_c_g_t_k_text_view.html#a0b6b99cde59ef1b1b3774e351fc442b3", null ],
    [ "getPixelsBelowLines", "interface_c_g_t_k_text_view.html#a25048a4c7978a7cc443e4701ff12d367", null ],
    [ "getPixelsInsideWrap", "interface_c_g_t_k_text_view.html#a250f9f28a26c1e063c1420193e62b312", null ],
    [ "getRightMargin", "interface_c_g_t_k_text_view.html#a7225bd06eff205a2b872f75a55d64262", null ],
    [ "getTabs", "interface_c_g_t_k_text_view.html#aaa74d244e49ed96adde3bb39b66f81ca", null ],
    [ "getVadjustment", "interface_c_g_t_k_text_view.html#ac3331d162cac81dac6521a0f133ba0a6", null ],
    [ "getVisibleRect:", "interface_c_g_t_k_text_view.html#aa7960e8957ffd64ea6754790799a9edb", null ],
    [ "getWindow:", "interface_c_g_t_k_text_view.html#a78f5a28375ec1889ffb622d9e93c637d", null ],
    [ "getWindowType:", "interface_c_g_t_k_text_view.html#accc21c2f26f74327f66899973f854ee0", null ],
    [ "getWrapMode", "interface_c_g_t_k_text_view.html#a742d0c247758f62d02686d40c339ebec", null ],
    [ "imContextFilterKeypress:", "interface_c_g_t_k_text_view.html#a29d6d08394dcf4059175ccd99d3f9c27", null ],
    [ "init", "interface_c_g_t_k_text_view.html#a342d68f5d22d25fdf87c3b0070759cf3", null ],
    [ "initWithBuffer:", "interface_c_g_t_k_text_view.html#a82bb03daf34faf5b67a13f607fb05590", null ],
    [ "moveChildWithChild:andXpos:andYpos:", "interface_c_g_t_k_text_view.html#a3696c980985853d679909eee7c489be2", null ],
    [ "moveMarkOnscreen:", "interface_c_g_t_k_text_view.html#abb91294f79a977d05088f24eabfb2714", null ],
    [ "moveVisuallyWithIter:andCount:", "interface_c_g_t_k_text_view.html#aeb57e9d37eb64480c33e9764860afe99", null ],
    [ "placeCursorOnscreen", "interface_c_g_t_k_text_view.html#a37ce998974529d395e938160deb43200", null ],
    [ "resetImContext", "interface_c_g_t_k_text_view.html#a6e5bdeb8c3869da386254cecdecd1194", null ],
    [ "scrollMarkOnscreen:", "interface_c_g_t_k_text_view.html#a99219ee799c96e01b641c95729714ea5", null ],
    [ "scrollToIterWithIter:andWithinMargin:andUseAlign:andXalign:andYalign:", "interface_c_g_t_k_text_view.html#aa8053fcc724caa320d096cc4efaaa8a0", null ],
    [ "scrollToMarkWithMark:andWithinMargin:andUseAlign:andXalign:andYalign:", "interface_c_g_t_k_text_view.html#a8d651c714885cab069a31925b88a2f1a", null ],
    [ "setAcceptsTab:", "interface_c_g_t_k_text_view.html#ac7f7d52f75deb911d6992431e5cc3330", null ],
    [ "setBorderWindowSizeWithType:andSize:", "interface_c_g_t_k_text_view.html#ad79f7b91e0bdc3e12b11154d74054926", null ],
    [ "setBuffer:", "interface_c_g_t_k_text_view.html#a4a03c30291f7d1487e603ea1ffc65040", null ],
    [ "setCursorVisible:", "interface_c_g_t_k_text_view.html#a8a15b0d6ad6ac588a65146e5f9c6ec28", null ],
    [ "setEditable:", "interface_c_g_t_k_text_view.html#a37d8684ecfc1199fc52f7925c8432d29", null ],
    [ "setIndent:", "interface_c_g_t_k_text_view.html#a219077fc1ea253ff6f9a00a7dcdc2c03", null ],
    [ "setInputHints:", "interface_c_g_t_k_text_view.html#aefa88f4710fe50c6bc5c5204ba87e615", null ],
    [ "setInputPurpose:", "interface_c_g_t_k_text_view.html#a430abe846120942776e044cb3d44a566", null ],
    [ "setJustification:", "interface_c_g_t_k_text_view.html#a02c3ca9f9b726148d96bd02b1521405b", null ],
    [ "setLeftMargin:", "interface_c_g_t_k_text_view.html#a6f009582f49a8ecf2f3866839aefed62", null ],
    [ "setOverwrite:", "interface_c_g_t_k_text_view.html#a5c2e0df7cfbbaeb271b4213ad4ad8033", null ],
    [ "setPixelsAboveLines:", "interface_c_g_t_k_text_view.html#a084dd6fba20d12c2dcb4422b3d610ce1", null ],
    [ "setPixelsBelowLines:", "interface_c_g_t_k_text_view.html#a776e63ac11904b97f59cdc9d5f8f9423", null ],
    [ "setPixelsInsideWrap:", "interface_c_g_t_k_text_view.html#ac9f5d989477aa7251b95f0d38a0e108f", null ],
    [ "setRightMargin:", "interface_c_g_t_k_text_view.html#a698c022ae352987a81bd1105ef79bbcf", null ],
    [ "setTabs:", "interface_c_g_t_k_text_view.html#ab1172376be857c4361cbcf5234f42f6a", null ],
    [ "setWrapMode:", "interface_c_g_t_k_text_view.html#a23e0940e99c9f31fe038e024e037bcca", null ],
    [ "startsDisplayLine:", "interface_c_g_t_k_text_view.html#ac63c133faf60febcdb9f4f1a8ed419f6", null ],
    [ "TEXTVIEW", "interface_c_g_t_k_text_view.html#a6b049599544745813a5be925e3a6aa28", null ],
    [ "windowToBufferCoordsWithWin:andWindowX:andWindowY:andBufferX:andBufferY:", "interface_c_g_t_k_text_view.html#a0344ca8dace7f5c529bb2e56f2442b38", null ]
];

==> coregtk-3.18.0.zip: coregtk-3.18.0/docs/html/interface_c_g_t_k_text_view.js <==
var interface_c_g_t_k_text_view =
[
    [ "addChildAtAnchorWithChild:andAnchor:", "interface_c_g_t_k_text_view.html#a785055611ec95ba45b3500b28c510f8e", null ],
    [ "addChildInWindowWithChild:andWhichWindow:andXpos:andYpos:", "interface_c_g_t_k_text_view.html#a53988e3b584cfda099218bf0b817fa3b", null ],
    [ "backwardDisplayLine:", "interface_c_g_t_k_text_view.html#a3aafd7992d437ebaaffc7c7343e6b93f", null ],
    [ "backwardDisplayLineStart:", "interface_c_g_t_k_text_view.html#a4e597cc1e3729a9ff67114e3c730d8ec", null ],
    [ "bufferToWindowCoordsWithWin:andBufferX:andBufferY:andWindowX:andWindowY:", "interface_c_g_t_k_text_view.html#a1b696a6ce9a3e8fe3cff0ba1b5f43a18", null ],
    [ "forwardDisplayLine:", "interface_c_g_t_k_text_view.html#a3a52fbcb4d12672f4f1103243407185b", null ],
    [ "forwardDisplayLineEnd:", "interface_c_g_t_k_text_view.html#afadc02a0e13b75cbb9034bd1be1fed68", null ],
    [ "getAcceptsTab", "interface_c_g_t_k_text_view.html#a09ee78b7970cacbfc8ca03f296d376f7", null ],
    [ "getBorderWindowSize:", "interface_c_g_t_k_text_view.html#a26d99de7816944dd7fa173cbed033dc4", null ],
    [ "getBottomMargin", "interface_c_g_t_k_text_view.html#a1b09bc992ad5e001ede61a5a1e1ed65e", null ],
    [ "getBuffer", "interface_c_g_t_k_text_view.html#abcaf6b1ec97e5dfc0bc140d37b0fba80", null ],
    [ "getCursorLocationsWithIter:andStrong:andWeak:", "interface_c_g_t_k_text_view.html#aa15c56fd47bc31c9b13825ab06d37c90", null ],
    [ "getCursorVisible", "interface_c_g_t_k_text_view.html#a1d53af03ae4df2ecb50c87eaf6fa5a01", null ],
    [ "getDefaultAttributes", "interface_c_g_t_k_text_view.html#a013ec9642813657b97b74e3880172774", null ],
    [ "getEditable", "interface_c_g_t_k_text_view.html#ac32345742c15e5800eb83ae80a4bd85c", null ],
    [ "getHadjustment", "interface_c_g_t_k_text_view.html#a10830068739dd1367a229146d7726ec8", null ],
    [ "getIndent", "interface_c_g_t_k_text_view.html#a0ee52b65855a553b85a9755c6c26beea", null ],
    [ "getInputHints", "interface_c_g_t_k_text_view.html#af1dbccba4d882f55748bf6ab48b55ca2", null ],
    [ "getInputPurpose", "interface_c_g_t_k_text_view.html#aa7eccee2c32eb8a4b4499462731cc5a5", null ],
    [ "getIterAtLocationWithIter:andX:andY:", "interface_c_g_t_k_text_view.html#aaa6bb40a1d1ac27c130e6595c35ad93a", null ],
    [ "getIterAtPositionWithIter:andTrailing:andX:andY:", "interface_c_g_t_k_text_view.html#a9054c2de391f7f08928c2348a1e651d6", null ],
    [ "getIterLocationWithIter:andLocation:", "interface_c_g_t_k_text_view.html#a3c63cd5e67feb2ac8c2100058e47bf6f", null ],
    [ "getJustification", "interface_c_g_t_k_text_view.html#a62c998ca5364e66b4ace5b7d0c73761e", null ],
    [ "getLeftMargin", "interface_c_g_t_k_text_view.html#a66db5566c75685c873f5f71f43413a63", null ],
    [ "getLineAtYWithTargetIter:andY:andLineTop:", "interface_c_g_t_k_text_view.html#aa8919f0d82d91aa9e4c8a09c0cc50d8d", null ],
    [ "getLineYrangeWithIter:andY:andHeight:", "interface_c_g_t_k_text_view.html#af6f6f423ef35b97047c14785de2acf61", null ],
    [ "getMonospace", "interface_c_g_t_k_text_view.html#a5b608018fa6c8f4d4489256d60d815b2", null ],
    [ "getOverwrite", "interface_c_g_t_k_text_view.html#ab6cbc76a44bc1e921ebdd647162b0fa1", null ],
    [ "getPixelsAboveLines", "interface_c_g_t_k_text_view.html#a0b6b99cde59ef1b1b3774e351fc442b3", null ],
    [ "getPixelsBelowLines", "interface_c_g_t_k_text_view.html#a25048a4c7978a7cc443e4701ff12d367", null ],
    [ "getPixelsInsideWrap", "interface_c_g_t_k_text_view.html#a250f9f28a26c1e063c1420193e62b312", null ],
    [ "getRightMargin", "interface_c_g_t_k_text_view.html#a7225bd06eff205a2b872f75a55d64262", null ],
    [ "getTabs", "interface_c_g_t_k_text_view.html#aaa74d244e49ed96adde3bb39b66f81ca", null ],
    [ "getTopMargin", "interface_c_g_t_k_text_view.html#af3762aa0826a76270b515619b11b34bf", null ],
    [ "getVadjustment", "interface_c_g_t_k_text_view.html#ac3331d162cac81dac6521a0f133ba0a6", null ],
    [ "getVisibleRect:", "interface_c_g_t_k_text_view.html#aa7960e8957ffd64ea6754790799a9edb", null ],
    [ "getWindow:", "interface_c_g_t_k_text_view.html#a78f5a28375ec1889ffb622d9e93c637d", null ],
    [ "getWindowType:", "interface_c_g_t_k_text_view.html#accc21c2f26f74327f66899973f854ee0", null ],
    [ "getWrapMode", "interface_c_g_t_k_text_view.html#a742d0c247758f62d02686d40c339ebec", null ],
    [ "imContextFilterKeypress:", "interface_c_g_t_k_text_view.html#a29d6d08394dcf4059175ccd99d3f9c27", null ],
    [ "init", "interface_c_g_t_k_text_view.html#a342d68f5d22d25fdf87c3b0070759cf3", null ],
    [ "initWithBuffer:", "interface_c_g_t_k_text_view.html#a82bb03daf34faf5b67a13f607fb05590", null ],
    [ "moveChildWithChild:andXpos:andYpos:", "interface_c_g_t_k_text_view.html#a3696c980985853d679909eee7c489be2", null ],
    [ "moveMarkOnscreen:", "interface_c_g_t_k_text_view.html#abb91294f79a977d05088f24eabfb2714", null ],
    [ "moveVisuallyWithIter:andCount:", "interface_c_g_t_k_text_view.html#aeb57e9d37eb64480c33e9764860afe99", null ],
    [ "placeCursorOnscreen", "interface_c_g_t_k_text_view.html#a37ce998974529d395e938160deb43200", null ],
    [ "resetImContext", "interface_c_g_t_k_text_view.html#a6e5bdeb8c3869da386254cecdecd1194", null ],
    [ "scrollMarkOnscreen:", "interface_c_g_t_k_text_view.html#a99219ee799c96e01b641c95729714ea5", null ],
    [ "scrollToIterWithIter:andWithinMargin:andUseAlign:andXalign:andYalign:", "interface_c_g_t_k_text_view.html#aa8053fcc724caa320d096cc4efaaa8a0", null ],
    [ "scrollToMarkWithMark:andWithinMargin:andUseAlign:andXalign:andYalign:", "interface_c_g_t_k_text_view.html#a8d651c714885cab069a31925b88a2f1a", null ],
    [ "setAcceptsTab:", "interface_c_g_t_k_text_view.html#ac7f7d52f75deb911d6992431e5cc3330", null ],
    [ "setBorderWindowSizeWithType:andSize:", "interface_c_g_t_k_text_view.html#ad79f7b91e0bdc3e12b11154d74054926", null ],
    [ "setBottomMargin:", "interface_c_g_t_k_text_view.html#adb1f2402f56f8fc84f4d356e0033e747", null ],
    [ "setBuffer:", "interface_c_g_t_k_text_view.html#a4a03c30291f7d1487e603ea1ffc65040", null ],
    [ "setCursorVisible:", "interface_c_g_t_k_text_view.html#a8a15b0d6ad6ac588a65146e5f9c6ec28", null ],
    [ "setEditable:", "interface_c_g_t_k_text_view.html#a37d8684ecfc1199fc52f7925c8432d29", null ],
    [ "setIndent:", "interface_c_g_t_k_text_view.html#a219077fc1ea253ff6f9a00a7dcdc2c03", null ],
    [ "setInputHints:", "interface_c_g_t_k_text_view.html#aefa88f4710fe50c6bc5c5204ba87e615", null ],
    [ "setInputPurpose:", "interface_c_g_t_k_text_view.html#a430abe846120942776e044cb3d44a566", null ],
    [ "setJustification:", "interface_c_g_t_k_text_view.html#a02c3ca9f9b726148d96bd02b1521405b", null ],
    [ "setLeftMargin:", "interface_c_g_t_k_text_view.html#a6f009582f49a8ecf2f3866839aefed62", null ],
    [ "setMonospace:", "interface_c_g_t_k_text_view.html#a004b44ff1aa3b2953df6d4e68745b166", null ],
    [ "setOverwrite:", "interface_c_g_t_k_text_view.html#a5c2e0df7cfbbaeb271b4213ad4ad8033", null ],
    [ "setPixelsAboveLines:", "interface_c_g_t_k_text_view.html#a084dd6fba20d12c2dcb4422b3d610ce1", null ],
    [ "setPixelsBelowLines:", "interface_c_g_t_k_text_view.html#a776e63ac11904b97f59cdc9d5f8f9423", null ],
    [ "setPixelsInsideWrap:", "interface_c_g_t_k_text_view.html#ac9f5d989477aa7251b95f0d38a0e108f", null ],
    [ "setRightMargin:", "interface_c_g_t_k_text_view.html#a698c022ae352987a81bd1105ef79bbcf", null ],
    [ "setTabs:", "interface_c_g_t_k_text_view.html#ab1172376be857c4361cbcf5234f42f6a", null ],
    [ "setTopMargin:", "interface_c_g_t_k_text_view.html#aa38ec33b4da51136acfb41586267dd46", null ],
    [ "setWrapMode:", "interface_c_g_t_k_text_view.html#a23e0940e99c9f31fe038e024e037bcca", null ],
    [ "startsDisplayLine:", "interface_c_g_t_k_text_view.html#ac63c133faf60febcdb9f4f1a8ed419f6", null ],
    [ "TEXTVIEW", "interface_c_g_t_k_text_view.html#a6b049599544745813a5be925e3a6aa28", null ],
    [ "windowToBufferCoordsWithWin:andWindowX:andWindowY:andBufferX:andBufferY:", "interface_c_g_t_k_text_view.html#a0344ca8dace7f5c529bb2e56f2442b38", null ]
];
